define([
  './wz-menu/wz-menu',
  './wz-table/index',
  './wz-table-server-side/index',
  './wz-data-table/wz-data-table',
  './wz-enter/wz-enter',
  './wz-dynamic/wz-dynamic',
  './wz-welcome-card/wz-welcome-card',
  './wz-bar/wz-bar',
  './wz-no-config/wz-no-config',
  './wz-config-item/wz-config-item',
  './wz-tag-filter/wz-tag-filter',
  './wz-data-table/wz-data-table',
  './wz-xml-file-editor/wz-xml-file-editor',
  './wz-multiple-selector/wz-multiple-selector',
  './wz-config-viewer/wz-config-viewer',
  './wz-discover/wz-discover',
  './wz-register-agent/wz-register-agent',
  './wz-svg/wz-svg',
  './wz-add-filter-chip/wz-add-filter-chip',
  './wz-head-toaster/wz-head-toaster',
  './wz-kbn-switch/wz-kbn-switch',
  './wz-alert-metrics/wz-alert-metrics',
  './wz-card-slider/wz-card-slider',
  './wz-logtest/wz-logtest',
  './wz-upload-files/wz-upload-files',
  './wz-iframe-onload/wz-iframe-onload',
  './wz-forbidden/wz-forbidden',
  './wz-rbac-prompt/wz-rbac-prompt',
], function () {})
